package com.sun.java.swing.plaf.motif;

import javax.swing.ComboBoxModel;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;
import javax.swing.AbstractListModel;
import java.awt.Component;
import javax.swing.DefaultListCellRenderer;
import javax.swing.SwingUtilities;
import java.awt.event.MouseEvent;
import java.awt.event.MouseAdapter;
import sun.swing.SwingUtilities2;
import java.util.Locale;
import javax.swing.UIManager;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.Box;
import javax.swing.BoxLayout;
import java.awt.BorderLayout;
import javax.swing.plaf.ComponentUI;
import javax.swing.ListSelectionModel;
import java.io.IOException;
import sun.awt.shell.ShellFolder;
import javax.swing.DefaultListSelectionModel;
import javax.swing.JComponent;
import java.awt.ComponentOrientation;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JButton;
import javax.swing.JPanel;
import java.awt.Insets;
import java.awt.Dimension;
import javax.swing.filechooser.FileFilter;
import javax.swing.JComboBox;
import javax.swing.JTextField;
import java.io.File;
import javax.swing.JList;
import javax.swing.plaf.basic.BasicFileChooserUI;

public class MotifFileChooserUI extends BasicFileChooserUI
{
    private MotifFileChooserUI.FilterComboBoxModel filterComboBoxModel;
    protected JList<File> directoryList;
    protected JList<File> fileList;
    protected JTextField pathField;
    protected JComboBox<FileFilter> filterComboBox;
    protected JTextField filenameTextField;
    private static final Dimension hstrut10;
    private static final Dimension vstrut10;
    private static final Insets insets;
    private static Dimension prefListSize;
    private static Dimension WITH_ACCELERATOR_PREF_SIZE;
    private static Dimension PREF_SIZE;
    private static final int MIN_WIDTH = 200;
    private static final int MIN_HEIGHT = 300;
    private static Dimension PREF_ACC_SIZE;
    private static Dimension ZERO_ACC_SIZE;
    private static Dimension MAX_SIZE;
    private static final Insets buttonMargin;
    private JPanel bottomPanel;
    protected JButton approveButton;
    private String enterFolderNameLabelText;
    private int enterFolderNameLabelMnemonic;
    private String enterFileNameLabelText;
    private int enterFileNameLabelMnemonic;
    private String filesLabelText;
    private int filesLabelMnemonic;
    private String foldersLabelText;
    private int foldersLabelMnemonic;
    private String pathLabelText;
    private int pathLabelMnemonic;
    private String filterLabelText;
    private int filterLabelMnemonic;
    private JLabel fileNameLabel;
    
    private void populateFileNameLabel() {
        if (this.getFileChooser().getFileSelectionMode() == 1) {
            this.fileNameLabel.setText(this.enterFolderNameLabelText);
            this.fileNameLabel.setDisplayedMnemonic(this.enterFolderNameLabelMnemonic);
        }
        else {
            this.fileNameLabel.setText(this.enterFileNameLabelText);
            this.fileNameLabel.setDisplayedMnemonic(this.enterFileNameLabelMnemonic);
        }
    }
    
    private String fileNameString(File file) {
        if (file == null) {
            return null;
        }
        JFileChooser fileChooser = this.getFileChooser();
        if (fileChooser.isDirectorySelectionEnabled() && !fileChooser.isFileSelectionEnabled()) {
            return file.getPath();
        }
        return file.getName();
    }
    
    private String fileNameString(File[] array) {
        StringBuffer sb = new StringBuffer();
        for (int n = 0; array != null && n < array.length; ++n) {
            if (n > 0) {
                sb.append(" ");
            }
            if (array.length > 1) {
                sb.append("\"");
            }
            sb.append(this.fileNameString(array[n]));
            if (array.length > 1) {
                sb.append("\"");
            }
        }
        return sb.toString();
    }
    
    public MotifFileChooserUI(JFileChooser b) {
        super(b);
        this.directoryList = null;
        this.fileList = null;
        this.pathField = null;
        this.filterComboBox = null;
        this.filenameTextField = null;
        this.enterFolderNameLabelText = null;
        this.enterFolderNameLabelMnemonic = 0;
        this.enterFileNameLabelText = null;
        this.enterFileNameLabelMnemonic = 0;
        this.filesLabelText = null;
        this.filesLabelMnemonic = 0;
        this.foldersLabelText = null;
        this.foldersLabelMnemonic = 0;
        this.pathLabelText = null;
        this.pathLabelMnemonic = 0;
        this.filterLabelText = null;
        this.filterLabelMnemonic = 0;
    }
    
    @Override
    public String getFileName() {
        if (this.filenameTextField != null) {
            return this.filenameTextField.getText();
        }
        return null;
    }
    
    @Override
    public void setFileName(String text) {
        if (this.filenameTextField != null) {
            this.filenameTextField.setText(text);
        }
    }
    
    @Override
    public String getDirectoryName() {
        return this.pathField.getText();
    }
    
    @Override
    public void setDirectoryName(String text) {
        this.pathField.setText(text);
    }
    
    @Override
    public void ensureFileIsVisible(JFileChooser fileChooser, File file) {
    }
    
    @Override
    public void rescanCurrentDirectory(JFileChooser fileChooser) {
        this.getModel().validateFileCache();
    }
    
    @Override
    public PropertyChangeListener createPropertyChangeListener(JFileChooser fileChooser) {
        return new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
                String propertyName = propertyChangeEvent.getPropertyName();
                if (propertyName.equals("SelectedFileChangedProperty")) {
                    File f = (File)propertyChangeEvent.getNewValue();
                    if (f != null) {
                        MotifFileChooserUI.this.setFileName(MotifFileChooserUI.this.getFileChooser().getName(f));
                    }
                }
                else if (propertyName.equals("SelectedFilesChangedProperty")) {
                    File[] array = (File[])(File[])propertyChangeEvent.getNewValue();
                    JFileChooser fileChooser2 = MotifFileChooserUI.this.getFileChooser();
                    if (array != null && array.length > 0 && (array.length > 1 || fileChooser2.isDirectorySelectionEnabled() || !array[0].isDirectory())) {
                        MotifFileChooserUI.this.setFileName(MotifFileChooserUI.access$000(MotifFileChooserUI.this, array));
                    }
                }
                else if (propertyName.equals("fileFilterChanged")) {
                    MotifFileChooserUI.this.fileList.clearSelection();
                }
                else if (propertyName.equals("directoryChanged")) {
                    MotifFileChooserUI.this.directoryList.clearSelection();
                    ListSelectionModel selectionModel = MotifFileChooserUI.this.directoryList.getSelectionModel();
                    if ((selectionModel instanceof DefaultListSelectionModel)) {
                        ((DefaultListSelectionModel)selectionModel).moveLeadSelectionIndex(0);
                        selectionModel.setAnchorSelectionIndex(0);
                    }
                    MotifFileChooserUI.this.fileList.clearSelection();
                    ListSelectionModel selectionModel2 = MotifFileChooserUI.this.fileList.getSelectionModel();
                    if ((selectionModel2 instanceof DefaultListSelectionModel)) {
                        ((DefaultListSelectionModel)selectionModel2).moveLeadSelectionIndex(0);
                        selectionModel2.setAnchorSelectionIndex(0);
                    }
                    if (MotifFileChooserUI.this.getFileChooser().getCurrentDirectory() != null) {
                        try {
                            MotifFileChooserUI.this.setDirectoryName(ShellFolder.getNormalizedFile((File)propertyChangeEvent.getNewValue()).getPath());
                        }
                        catch (IOException ex) {
                            MotifFileChooserUI.this.setDirectoryName(((File)propertyChangeEvent.getNewValue()).getAbsolutePath());
                        }
                        if (MotifFileChooserUI.this.getFileChooser().getFileSelectionMode() == 1 && !MotifFileChooserUI.this.getFileChooser().isMultiSelectionEnabled()) {
                            MotifFileChooserUI.this.setFileName(MotifFileChooserUI.this.getDirectoryName());
                        }
                    }
                }
                else if (propertyName.equals("fileSelectionChanged")) {
                    if (MotifFileChooserUI.this.fileNameLabel != null) {
                        MotifFileChooserUI.access$200(MotifFileChooserUI.this);
                    }
                    MotifFileChooserUI.this.directoryList.clearSelection();
                }
                else if (propertyName.equals("MultiSelectionEnabledChangedProperty")) {
                    if (MotifFileChooserUI.this.getFileChooser().isMultiSelectionEnabled()) {
                        MotifFileChooserUI.this.fileList.setSelectionMode(2);
                    }
                    else {
                        MotifFileChooserUI.this.fileList.setSelectionMode(0);
                        MotifFileChooserUI.this.fileList.clearSelection();
                        MotifFileChooserUI.this.getFileChooser().setSelectedFiles((File[])null);
                    }
                }
                else if (propertyName.equals("AccessoryChangedProperty")) {
                    if (MotifFileChooserUI.this.getAccessoryPanel() != null) {
                        if (propertyChangeEvent.getOldValue() != null) {
                            MotifFileChooserUI.this.getAccessoryPanel().remove((JComponent)propertyChangeEvent.getOldValue());
                        }
                        JComponent comp = (JComponent)propertyChangeEvent.getNewValue();
                        if (comp != null) {
                            MotifFileChooserUI.this.getAccessoryPanel().add(comp, "Center");
                            MotifFileChooserUI.this.getAccessoryPanel().setPreferredSize(MotifFileChooserUI.PREF_ACC_SIZE);
                            MotifFileChooserUI.this.getAccessoryPanel().setMaximumSize(MotifFileChooserUI.MAX_SIZE);
                        }
                        else {
                            MotifFileChooserUI.this.getAccessoryPanel().setPreferredSize(MotifFileChooserUI.ZERO_ACC_SIZE);
                            MotifFileChooserUI.this.getAccessoryPanel().setMaximumSize(MotifFileChooserUI.ZERO_ACC_SIZE);
                        }
                    }
                }
                else if (propertyName.equals("ApproveButtonTextChangedProperty") || propertyName.equals("ApproveButtonToolTipTextChangedProperty") || propertyName.equals("DialogTypeChangedProperty")) {
                    MotifFileChooserUI.this.approveButton.setText(MotifFileChooserUI.this.getApproveButtonText(MotifFileChooserUI.this.getFileChooser()));
                    MotifFileChooserUI.this.approveButton.setToolTipText(MotifFileChooserUI.this.getApproveButtonToolTipText(MotifFileChooserUI.this.getFileChooser()));
                }
                else if (propertyName.equals("ControlButtonsAreShownChangedProperty")) {
                    MotifFileChooserUI.access$600(MotifFileChooserUI.this, propertyChangeEvent);
                }
                else if (propertyName.equals("componentOrientation")) {
                    ComponentOrientation o = (ComponentOrientation)propertyChangeEvent.getNewValue();
                    JFileChooser fileChooser = (JFileChooser)propertyChangeEvent.getSource();
                    if (o != (ComponentOrientation)propertyChangeEvent.getOldValue()) {
                        fileChooser.applyComponentOrientation(o);
                    }
                }
            }
        };
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new MotifFileChooserUI((JFileChooser)component);
    }
    
    @Override
    public void installUI(JComponent c) {
        super.installUI(c);
    }
    
    @Override
    public void uninstallUI(JComponent c) {
        c.removePropertyChangeListener(this.filterComboBoxModel);
        this.approveButton.removeActionListener(this.getApproveSelectionAction());
        this.filenameTextField.removeActionListener(this.getApproveSelectionAction());
        super.uninstallUI(c);
    }
    
    @Override
    public void installComponents(JFileChooser fc) {
        fc.setLayout(new BorderLayout(10, 10));
        fc.setAlignmentX(0.5f);
        JPanel panel = new JPanel() {
            @Override
            public Insets getInsets() {
                return MotifFileChooserUI.insets;
            }
        };
        panel.setInheritsPopupMenu(true);
        this.align(panel);
        panel.setLayout(new BoxLayout(panel, 3));
        fc.add(panel, "Center");
        JLabel comp = new JLabel(this.pathLabelText);
        comp.setDisplayedMnemonic(this.pathLabelMnemonic);
        this.align(comp);
        panel.add(comp);
        File currentDirectory = fc.getCurrentDirectory();
        final String path = null;
        if (currentDirectory != null) {
            path = currentDirectory.getPath();
        }
        (this.pathField = new JTextField(path) {
            @Override
            public Dimension getMaximumSize() {
                Dimension maximumSize = super.getMaximumSize();
                maximumSize.height = this.getPreferredSize().height;
                return maximumSize;
            }
        }).setInheritsPopupMenu(true);
        comp.setLabelFor(this.pathField);
        this.align(this.pathField);
        this.pathField.addActionListener(this.getUpdateAction());
        panel.add(this.pathField);
        panel.add(Box.createRigidArea(MotifFileChooserUI.vstrut10));
        JPanel o = new JPanel();
        o.setLayout(new BoxLayout(o, 2));
        this.align(o);
        JPanel o2 = new JPanel();
        o2.setLayout(new BoxLayout(o2, 3));
        this.align(o2);
        JLabel comp2 = new JLabel(this.filterLabelText);
        comp2.setDisplayedMnemonic(this.filterLabelMnemonic);
        this.align(comp2);
        o2.add(comp2);
        (this.filterComboBox = new JComboBox<FileFilter>() {
            @Override
            public Dimension getMaximumSize() {
                Dimension maximumSize = super.getMaximumSize();
                maximumSize.height = this.getPreferredSize().height;
                return maximumSize;
            }
        }).setInheritsPopupMenu(true);
        comp2.setLabelFor(this.filterComboBox);
        this.filterComboBoxModel = this.createFilterComboBoxModel();
        this.filterComboBox.setModel(this.filterComboBoxModel);
        this.filterComboBox.setRenderer(this.createFilterComboBoxRenderer());
        fc.addPropertyChangeListener(this.filterComboBoxModel);
        this.align(this.filterComboBox);
        o2.add(this.filterComboBox);
        JLabel comp3 = new JLabel(this.foldersLabelText);
        comp3.setDisplayedMnemonic(this.foldersLabelMnemonic);
        this.align(comp3);
        o2.add(comp3);
        JScrollPane directoryList = this.createDirectoryList();
        directoryList.getVerticalScrollBar().setFocusable(false);
        directoryList.getHorizontalScrollBar().setFocusable(false);
        directoryList.setInheritsPopupMenu(true);
        comp3.setLabelFor(directoryList.getViewport().getView());
        o2.add(directoryList);
        o2.setInheritsPopupMenu(true);
        JPanel o3 = new JPanel();
        this.align(o3);
        o3.setLayout(new BoxLayout(o3, 3));
        o3.setInheritsPopupMenu(true);
        JLabel comp4 = new JLabel(this.filesLabelText);
        comp4.setDisplayedMnemonic(this.filesLabelMnemonic);
        this.align(comp4);
        o3.add(comp4);
        JScrollPane filesList = this.createFilesList();
        comp4.setLabelFor(filesList.getViewport().getView());
        o3.add(filesList);
        filesList.setInheritsPopupMenu(true);
        o.add(o2);
        o.add(Box.createRigidArea(MotifFileChooserUI.hstrut10));
        o.add(o3);
        o.setInheritsPopupMenu(true);
        JPanel accessoryPanel = this.getAccessoryPanel();
        JComponent accessory = fc.getAccessory();
        if (accessoryPanel != null) {
            if (accessory == null) {
                accessoryPanel.setPreferredSize(MotifFileChooserUI.ZERO_ACC_SIZE);
                accessoryPanel.setMaximumSize(MotifFileChooserUI.ZERO_ACC_SIZE);
            }
            else {
                this.getAccessoryPanel().add(accessory, "Center");
                accessoryPanel.setPreferredSize(MotifFileChooserUI.PREF_ACC_SIZE);
                accessoryPanel.setMaximumSize(MotifFileChooserUI.MAX_SIZE);
            }
            this.align(accessoryPanel);
            o.add(accessoryPanel);
            accessoryPanel.setInheritsPopupMenu(true);
        }
        panel.add(o);
        panel.add(Box.createRigidArea(MotifFileChooserUI.vstrut10));
        this.fileNameLabel = new JLabel();
        this.populateFileNameLabel();
        this.align(this.fileNameLabel);
        panel.add(this.fileNameLabel);
        (this.filenameTextField = new JTextField() {
            @Override
            public Dimension getMaximumSize() {
                Dimension maximumSize = super.getMaximumSize();
                maximumSize.height = this.getPreferredSize().height;
                return maximumSize;
            }
        }).setInheritsPopupMenu(true);
        this.fileNameLabel.setLabelFor(this.filenameTextField);
        this.filenameTextField.addActionListener(this.getApproveSelectionAction());
        this.align(this.filenameTextField);
        this.filenameTextField.setAlignmentX(0.0f);
        panel.add(this.filenameTextField);
        (this.bottomPanel = this.getBottomPanel()).add(new JSeparator(), "North");
        JPanel o4 = new JPanel();
        this.align(o4);
        o4.setLayout(new BoxLayout(o4, 2));
        o4.add(Box.createGlue());
        (this.approveButton = new JButton(this.getApproveButtonText(fc)) {
            @Override
            public Dimension getMaximumSize() {
                return new Dimension(MotifFileChooserUI.MAX_SIZE.width, this.getPreferredSize().height);
            }
        }).setMnemonic(this.getApproveButtonMnemonic(fc));
        this.approveButton.setToolTipText(this.getApproveButtonToolTipText(fc));
        this.approveButton.setInheritsPopupMenu(true);
        this.align(this.approveButton);
        this.approveButton.setMargin(MotifFileChooserUI.buttonMargin);
        this.approveButton.addActionListener(this.getApproveSelectionAction());
        o4.add(this.approveButton);
        o4.add(Box.createGlue());
        MotifFileChooserUI.7 comp5 = new JButton(this.updateButtonText) {
            @Override
            public Dimension getMaximumSize() {
                return new Dimension(MotifFileChooserUI.MAX_SIZE.width, this.getPreferredSize().height);
            }
        };
        comp5.setMnemonic(this.updateButtonMnemonic);
        comp5.setToolTipText(this.updateButtonToolTipText);
        comp5.setInheritsPopupMenu(true);
        this.align(comp5);
        comp5.setMargin(MotifFileChooserUI.buttonMargin);
        comp5.addActionListener(this.getUpdateAction());
        o4.add(comp5);
        o4.add(Box.createGlue());
        MotifFileChooserUI.8 comp6 = new JButton(this.cancelButtonText) {
            @Override
            public Dimension getMaximumSize() {
                return new Dimension(MotifFileChooserUI.MAX_SIZE.width, this.getPreferredSize().height);
            }
        };
        comp6.setMnemonic(this.cancelButtonMnemonic);
        comp6.setToolTipText(this.cancelButtonToolTipText);
        comp6.setInheritsPopupMenu(true);
        this.align(comp6);
        comp6.setMargin(MotifFileChooserUI.buttonMargin);
        comp6.addActionListener(this.getCancelSelectionAction());
        o4.add(comp6);
        o4.add(Box.createGlue());
        MotifFileChooserUI.9 comp7 = new JButton(this.helpButtonText) {
            @Override
            public Dimension getMaximumSize() {
                return new Dimension(MotifFileChooserUI.MAX_SIZE.width, this.getPreferredSize().height);
            }
        };
        comp7.setMnemonic(this.helpButtonMnemonic);
        comp7.setToolTipText(this.helpButtonToolTipText);
        this.align(comp7);
        comp7.setMargin(MotifFileChooserUI.buttonMargin);
        comp7.setEnabled(false);
        comp7.setInheritsPopupMenu(true);
        o4.add(comp7);
        o4.add(Box.createGlue());
        o4.setInheritsPopupMenu(true);
        this.bottomPanel.add(o4, "South");
        this.bottomPanel.setInheritsPopupMenu(true);
        if (fc.getControlButtonsAreShown()) {
            fc.add(this.bottomPanel, "South");
        }
    }
    
    protected JPanel getBottomPanel() {
        if (this.bottomPanel == null) {
            this.bottomPanel = new JPanel(new BorderLayout(0, 4));
        }
        return this.bottomPanel;
    }
    
    private void doControlButtonsChanged(PropertyChangeEvent propertyChangeEvent) {
        if (this.getFileChooser().getControlButtonsAreShown()) {
            this.getFileChooser().add(this.bottomPanel, "South");
        }
        else {
            this.getFileChooser().remove(this.getBottomPanel());
        }
    }
    
    @Override
    public void uninstallComponents(JFileChooser fileChooser) {
        fileChooser.removeAll();
        this.bottomPanel = null;
        if (this.filterComboBoxModel != null) {
            fileChooser.removePropertyChangeListener(this.filterComboBoxModel);
        }
    }
    
    @Override
    protected void installStrings(JFileChooser fc) {
        super.installStrings(fc);
        Locale locale = fc.getLocale();
        this.enterFolderNameLabelText = UIManager.getString("FileChooser.enterFolderNameLabelText", locale);
        this.enterFolderNameLabelMnemonic = (int)this.getMnemonic("FileChooser.enterFolderNameLabelMnemonic", locale);
        this.enterFileNameLabelText = UIManager.getString("FileChooser.enterFileNameLabelText", locale);
        this.enterFileNameLabelMnemonic = (int)this.getMnemonic("FileChooser.enterFileNameLabelMnemonic", locale);
        this.filesLabelText = UIManager.getString("FileChooser.filesLabelText", locale);
        this.filesLabelMnemonic = (int)this.getMnemonic("FileChooser.filesLabelMnemonic", locale);
        this.foldersLabelText = UIManager.getString("FileChooser.foldersLabelText", locale);
        this.foldersLabelMnemonic = (int)this.getMnemonic("FileChooser.foldersLabelMnemonic", locale);
        this.pathLabelText = UIManager.getString("FileChooser.pathLabelText", locale);
        this.pathLabelMnemonic = (int)this.getMnemonic("FileChooser.pathLabelMnemonic", locale);
        this.filterLabelText = UIManager.getString("FileChooser.filterLabelText", locale);
        this.filterLabelMnemonic = (int)this.getMnemonic("FileChooser.filterLabelMnemonic", locale);
    }
    
    private Integer getMnemonic(String key, Locale l) {
        return Integer.valueOf(SwingUtilities2.getUIDefaultsInt(key, l));
    }
    
    @Override
    protected void installIcons(JFileChooser fileChooser) {
    }
    
    @Override
    protected void uninstallIcons(JFileChooser fileChooser) {
    }
    
    protected JScrollPane createFilesList() {
        this.fileList = new JList();
        if (this.getFileChooser().isMultiSelectionEnabled()) {
            this.fileList.setSelectionMode(2);
        }
        else {
            this.fileList.setSelectionMode(0);
        }
        this.fileList.setModel(new MotifFileChooserUI.MotifFileListModel());
        this.fileList.getSelectionModel().removeSelectionInterval(0, 0);
        this.fileList.setCellRenderer(new MotifFileChooserUI.FileCellRenderer());
        this.fileList.addListSelectionListener(this.createListSelectionListener(this.getFileChooser()));
        this.fileList.addMouseListener(this.createDoubleClickListener(this.getFileChooser(), this.fileList));
        this.fileList.addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent anEvent) {
                JFileChooser fileChooser = MotifFileChooserUI.this.getFileChooser();
                if (SwingUtilities.isLeftMouseButton(anEvent) && !fileChooser.isMultiSelectionEnabled()) {
                    int loc2IndexFileList = SwingUtilities2.loc2IndexFileList(MotifFileChooserUI.this.fileList, anEvent.getPoint());
                    if (loc2IndexFileList >= 0) {
                        MotifFileChooserUI.this.setFileName(fileChooser.getName((File)MotifFileChooserUI.this.fileList.getModel().getElementAt(loc2IndexFileList)));
                    }
                }
            }
        });
        this.align(this.fileList);
        JScrollPane scrollPane = new JScrollPane(this.fileList);
        scrollPane.setPreferredSize(MotifFileChooserUI.prefListSize);
        scrollPane.setMaximumSize(MotifFileChooserUI.MAX_SIZE);
        this.align(scrollPane);
        this.fileList.setInheritsPopupMenu(true);
        scrollPane.setInheritsPopupMenu(true);
        return scrollPane;
    }
    
    protected JScrollPane createDirectoryList() {
        this.align(this.directoryList = new JList());
        this.directoryList.setCellRenderer(new MotifFileChooserUI.DirectoryCellRenderer());
        this.directoryList.setModel(new MotifFileChooserUI.MotifDirectoryListModel());
        this.directoryList.getSelectionModel().removeSelectionInterval(0, 0);
        this.directoryList.addMouseListener(this.createDoubleClickListener(this.getFileChooser(), this.directoryList));
        this.directoryList.addListSelectionListener(this.createListSelectionListener(this.getFileChooser()));
        this.directoryList.setInheritsPopupMenu(true);
        JScrollPane scrollPane = new JScrollPane(this.directoryList);
        scrollPane.setMaximumSize(MotifFileChooserUI.MAX_SIZE);
        scrollPane.setPreferredSize(MotifFileChooserUI.prefListSize);
        scrollPane.setInheritsPopupMenu(true);
        this.align(scrollPane);
        return scrollPane;
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        Dimension dimension = (this.getFileChooser().getAccessory() != null) ? MotifFileChooserUI.WITH_ACCELERATOR_PREF_SIZE : MotifFileChooserUI.PREF_SIZE;
        Dimension preferredLayoutSize = component.getLayout().preferredLayoutSize(component);
        if (preferredLayoutSize != null) {
            return new Dimension((preferredLayoutSize.width < dimension.width) ? dimension.width : preferredLayoutSize.width, (preferredLayoutSize.height < dimension.height) ? dimension.height : preferredLayoutSize.height);
        }
        return dimension;
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        return new Dimension(200, 300);
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
    }
    
    protected void align(JComponent component) {
        component.setAlignmentX(0.0f);
        component.setAlignmentY(0.0f);
    }
    
    protected MotifFileChooserUI.FilterComboBoxModel createFilterComboBoxModel() {
        return new MotifFileChooserUI.FilterComboBoxModel();
    }
    
    protected MotifFileChooserUI.FilterComboBoxRenderer createFilterComboBoxRenderer() {
        return new MotifFileChooserUI.FilterComboBoxRenderer();
    }
    
    @Override
    protected JButton getApproveButton(JFileChooser fileChooser) {
        return this.approveButton;
    }
    
    static String access$000(MotifFileChooserUI motifFileChooserUI, File[] array) {
        return motifFileChooserUI.fileNameString(array);
    }
    
    static void access$200(MotifFileChooserUI motifFileChooserUI) {
        motifFileChooserUI.populateFileNameLabel();
    }
    
    static void access$600(MotifFileChooserUI motifFileChooserUI, PropertyChangeEvent propertyChangeEvent) {
        motifFileChooserUI.doControlButtonsChanged(propertyChangeEvent);
    }
    
    static {
        hstrut10 = new Dimension(10, 1);
        vstrut10 = new Dimension(1, 10);
        insets = new Insets(10, 10, 10, 10);
        MotifFileChooserUI.prefListSize = new Dimension(75, 150);
        MotifFileChooserUI.WITH_ACCELERATOR_PREF_SIZE = new Dimension(650, 450);
        MotifFileChooserUI.PREF_SIZE = new Dimension(350, 450);
        MotifFileChooserUI.PREF_ACC_SIZE = new Dimension(10, 10);
        MotifFileChooserUI.ZERO_ACC_SIZE = new Dimension(1, 1);
        MotifFileChooserUI.MAX_SIZE = new Dimension(32767, 32767);
        buttonMargin = new Insets(3, 3, 3, 3);
    }
    
    protected class FileCellRenderer extends DefaultListCellRenderer
    {
        @Override
        public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
            super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
            this.setText(MotifFileChooserUI.this.getFileChooser().getName((File)value));
            this.setInheritsPopupMenu(true);
            return this;
        }
    }
    
    protected class DirectoryCellRenderer extends DefaultListCellRenderer
    {
        @Override
        public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
            super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
            this.setText(MotifFileChooserUI.this.getFileChooser().getName((File)value));
            this.setInheritsPopupMenu(true);
            return this;
        }
    }
    
    protected class MotifDirectoryListModel extends AbstractListModel<File> implements ListDataListener
    {
        public MotifDirectoryListModel() {
            MotifFileChooserUI.this.getModel().addListDataListener(this);
        }
        
        @Override
        public int getSize() {
            return MotifFileChooserUI.this.getModel().getDirectories().size();
        }
        
        @Override
        public File getElementAt(int index) {
            return (File)MotifFileChooserUI.this.getModel().getDirectories().elementAt(index);
        }
        
        @Override
        public void intervalAdded(ListDataEvent listDataEvent) {
            this.fireIntervalAdded(this, listDataEvent.getIndex0(), listDataEvent.getIndex1());
        }
        
        @Override
        public void intervalRemoved(ListDataEvent listDataEvent) {
            this.fireIntervalRemoved(this, listDataEvent.getIndex0(), listDataEvent.getIndex1());
        }
        
        public void fireContentsChanged() {
            super.fireContentsChanged(this, 0, MotifFileChooserUI.this.getModel().getDirectories().size() - 1);
        }
        
        @Override
        public void contentsChanged(ListDataEvent listDataEvent) {
            this.fireContentsChanged();
        }
    }
    
    protected class MotifFileListModel extends AbstractListModel<File> implements ListDataListener
    {
        public MotifFileListModel() {
            MotifFileChooserUI.this.getModel().addListDataListener(this);
        }
        
        @Override
        public int getSize() {
            return MotifFileChooserUI.this.getModel().getFiles().size();
        }
        
        public boolean contains(Object o) {
            return MotifFileChooserUI.this.getModel().getFiles().contains(o);
        }
        
        public int indexOf(Object o) {
            return MotifFileChooserUI.this.getModel().getFiles().indexOf(o);
        }
        
        @Override
        public File getElementAt(int index) {
            return (File)MotifFileChooserUI.this.getModel().getFiles().elementAt(index);
        }
        
        @Override
        public void intervalAdded(ListDataEvent listDataEvent) {
            this.fireIntervalAdded(this, listDataEvent.getIndex0(), listDataEvent.getIndex1());
        }
        
        @Override
        public void intervalRemoved(ListDataEvent listDataEvent) {
            this.fireIntervalRemoved(this, listDataEvent.getIndex0(), listDataEvent.getIndex1());
        }
        
        public void fireContentsChanged() {
            super.fireContentsChanged(this, 0, MotifFileChooserUI.this.getModel().getFiles().size() - 1);
        }
        
        @Override
        public void contentsChanged(ListDataEvent listDataEvent) {
            this.fireContentsChanged();
        }
    }
    
    public class FilterComboBoxRenderer extends DefaultListCellRenderer
    {
        @Override
        public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
            super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
            if (value != null && value instanceof FileFilter) {
                this.setText(((FileFilter)value).getDescription());
                return this;
            }
            return this;
        }
    }
    
    protected class FilterComboBoxModel extends AbstractListModel<FileFilter> implements ComboBoxModel<FileFilter>, PropertyChangeListener
    {
        protected FileFilter[] filters;
        
        protected FilterComboBoxModel() {
            this.filters = MotifFileChooserUI.this.getFileChooser().getChoosableFileFilters();
        }
        
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            String propertyName = propertyChangeEvent.getPropertyName();
            if (propertyName.equals("ChoosableFileFilterChangedProperty")) {
                this.filters = (FileFilter[])(FileFilter[])propertyChangeEvent.getNewValue();
                this.fireContentsChanged(this, -1, -1);
            }
            else if (propertyName.equals("fileFilterChanged")) {
                this.fireContentsChanged(this, -1, -1);
            }
        }
        
        @Override
        public void setSelectedItem(Object o) {
            if (o != null) {
                MotifFileChooserUI.this.getFileChooser().setFileFilter((FileFilter)o);
                this.fireContentsChanged(this, -1, -1);
            }
        }
        
        @Override
        public Object getSelectedItem() {
            FileFilter fileFilter = MotifFileChooserUI.this.getFileChooser().getFileFilter();
            boolean n = false;
            if (fileFilter != null) {
                FileFilter[] filters = this.filters;
                for (int length = filters.length, i = 0; i < length; ++i) {
                    if (filters[i] == fileFilter) {
                        n = true;
                    }
                }
                if (n == 0) {
                    MotifFileChooserUI.this.getFileChooser().addChoosableFileFilter(fileFilter);
                }
            }
            return MotifFileChooserUI.this.getFileChooser().getFileFilter();
        }
        
        @Override
        public int getSize() {
            if (this.filters != null) {
                return this.filters.length;
            }
            return 0;
        }
        
        @Override
        public FileFilter getElementAt(int n) {
            if (n > this.getSize() - 1) {
                return MotifFileChooserUI.this.getFileChooser().getFileFilter();
            }
            if (this.filters != null) {
                return this.filters[n];
            }
            return null;
        }
    }
}
